/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.overview;

import org.infinispan.api.BasicCache;
import org.infinispan.api.BasicCacheContainer;
import org.infinispan.configuration.cache.CacheMode;
import org.infinispan.configuration.cache.Configuration;
import org.infinispan.configuration.cache.ConfigurationBuilder;
import org.infinispan.configuration.global.GlobalConfiguration;
import org.infinispan.configuration.global.GlobalConfigurationBuilder;
import org.infinispan.eviction.EvictionStrategy;
import org.infinispan.manager.DefaultCacheManager;

public class MainCacheTest {

    private static BasicCacheContainer manager;

    public static BasicCacheContainer getCacheContainer() {
        if (manager == null) {
            GlobalConfiguration glob = new GlobalConfigurationBuilder().nonClusteredDefault().globalJmxStatistics().enable()
                    .jmxDomain("overview").build();
            Configuration loc = new ConfigurationBuilder().clustering().cacheMode(CacheMode.LOCAL).eviction().maxEntries(100)
                    .strategy(EvictionStrategy.LIRS).loaders().passivation(false).build();
            manager = new DefaultCacheManager(glob, loc, true);
        }
        return manager;
    }

    public static void main(String[] args) {
        BasicCache<Integer, String> basicCache = getCacheContainer().getCache("CACHE_NAME");
        // HashMap<Integer, String> cache = new HashMap<Integer, String>();
        // add 5 key-value to each caches
        basicCache.put(965, "value965");
        basicCache.put(950, "value950");
        basicCache.put(937, "value937");
        basicCache.put(923, "value923");
        basicCache.put(837, "value837");

        // size should be 5, but output is 4
        System.out.println("basicCache : " + basicCache.size());
        System.out.println("basicCache keySet: " + basicCache.keySet());
    }

}
